@@ -215,9 +215,8 @@ delete_cygwin_fd (assuan_fd_t sockfd)
 }
 
 
-#ifdef HAVE_W32CE_SYSTEM
-static wchar_t *
-utf8_to_wchar (const char *string)
+wchar_t *
+_assuan_utf8_to_wchar (const char *string)
 {
   int n;
   size_t nbytes;
@@ -261,7 +260,7 @@ MyCreateFile (LPCSTR lpFileName, DWORD dwDesiredAccess, DWORD dwSharedMode,
   HANDLE result;
   int err;
 
-  filename = utf8_to_wchar (lpFileName);
+  filename = _assuan_utf8_to_wchar (lpFileName);
   if (!filename)
     return INVALID_HANDLE_VALUE;
 
@@ -279,7 +278,7 @@ MyDeleteFile (LPCSTR lpFileName)
   wchar_t *filename;
   int result, err;
 
-  filename = utf8_to_wchar (lpFileName);
+  filename = _assuan_utf8_to_wchar (lpFileName);
   if (!filename)
     return 0;
 
@@ -289,10 +288,7 @@ MyDeleteFile (LPCSTR lpFileName)
   SetLastError (err);
   return result;
 }
-#else /*!HAVE_W32CE_SYSTEM*/
-#define MyCreateFile CreateFileA
-#define MyDeleteFile DeleteFileA
-#endif /*!HAVE_W32CE_SYSTEM*/
+
 
 int
 _assuan_sock_wsa2errno (int err)
@@ -345,17 +341,17 @@ static int
 read_port_and_nonce (const char *fname, unsigned short *port, char *nonce,
                      int *cygwin)
 {
-  FILE *fp;
+  estream_t fp;
   char buffer[50], *p;
   size_t nread;
   int aval;
 
   *cygwin = 0;
-  fp = fopen (fname, "rb");
+  fp = gpgrt_fopen (fname, "rb");
   if (!fp)
     return -1;
-  nread = fread (buffer, 1, sizeof buffer - 1, fp);
-  fclose (fp);
+  nread = gpgrt_fread (buffer, 1, sizeof buffer - 1, fp);
+  gpgrt_fclose (fp);
   if (!nread)
     {
       gpg_err_set_errno (ENOENT);
